@@ -12,6 +12,10 @@ def secret_list(request):
         request, "secret_list.html", {"secret_files": models.SecretFile.objects.all()}
     )
 
+def secret_list_some_desc(request):
+    return render(
+        request, "secret_list_some_desc.html", {"secret_files": models.SecretFile.objects.all()}
+    )
 
 def secret_list_nulls_first(request):
     return render(
@@ -34,6 +38,10 @@ def jinja_secret_list(request):
         request, "secret_list.jinja2", {"secret_files": models.SecretFile.objects.all()}
     )
 
+def jinja_secret_list_some_desc(request):
+    return render(
+        request, "secret_list_some_desc.jinja2", {"secret_files": models.SecretFile.objects.all()}
+    )
 
 def jinja_secret_list_nulls_first(request):
     return render(
